@@ -51,6 +51,7 @@
 #include <arpa/inet.h>
 #include <net/if.h>
 #include <math.h> // fabs()
+#include <unistd.h>
 
 #include "_psutil_common.h"
 #include "_psutil_posix.h"
@@ -58,6 +59,8 @@
 #include "arch/solaris/environ.h"
 
 #define PSUTIL_TV2DOUBLE(t) (((t).tv_nsec * 0.000000001) + (t).tv_sec)
+#define GETSTATE(m) ((struct module_state*)PyModule_GetState(m))
+#define INITERROR return NULL
 
 
 /*
@@ -129,7 +132,7 @@ psutil_proc_basic_info(PyObject *self, PyObject *args) {
  */
 static int
 cstrings_array_to_string(char **joined, char ** array, size_t count, char dm) {
-    int i;
+    size_t i;
     size_t total_length = 0;
     size_t item_length = 0;
     char *result = NULL;
@@ -353,7 +356,7 @@ psutil_proc_cpu_times(PyObject *self, PyObject *args) {
  */
 static PyObject *
 psutil_proc_cpu_num(PyObject *self, PyObject *args) {
-    int fd = NULL;
+    int fd = -1;
     int pid;
     char path[1000];
     struct prheader header;
@@ -647,11 +650,11 @@ psutil_users(PyObject *self, PyObject *args) {
         if (! py_hostname)
             goto error;
         py_tuple = Py_BuildValue(
-            "(OOOfOi)",
+            "(OOOdOi)",
             py_username,              // username
             py_tty,                   // tty
             py_hostname,              // hostname
-            (float)ut->ut_tv.tv_sec,  // tstamp
+            (double)ut->ut_tv.tv_sec,  // tstamp
             py_user_proc,             // (bool) user process
             ut->ut_pid                // process id
         );
@@ -1659,6 +1662,7 @@ PsutilMethods[] = {
     {"users", psutil_users, METH_VARARGS},
 
     // --- others
+    {"check_pid_range", psutil_check_pid_range, METH_VARARGS},
     {"set_debug", psutil_set_debug, METH_VARARGS},
 
     {NULL, NULL, 0, NULL}
@@ -1669,13 +1673,6 @@ struct module_state {
     PyObject *error;
 };
 
-#if PY_MAJOR_VERSION >= 3
-#define GETSTATE(m) ((struct module_state*)PyModule_GetState(m))
-#else
-#define GETSTATE(m) (&_state)
-#endif
-
-#if PY_MAJOR_VERSION >= 3
 
 static int
 psutil_sunos_traverse(PyObject *m, visitproc visit, void *arg) {
@@ -1701,24 +1698,17 @@ static struct PyModuleDef moduledef = {
     NULL
 };
 
-#define INITERROR return NULL
 
-PyMODINIT_FUNC PyInit__psutil_sunos(void)
-
-#else
-#define INITERROR return
-
-void init_psutil_sunos(void)
-#endif
-{
-#if PY_MAJOR_VERSION >= 3
+PyMODINIT_FUNC
+PyInit__psutil_sunos(void) {
     PyObject *module = PyModule_Create(&moduledef);
-#else
-    PyObject *module = Py_InitModule("_psutil_sunos", PsutilMethods);
-#endif
     if (module == NULL)
         INITERROR;
 
+#ifdef Py_GIL_DISABLED
+    PyUnstable_Module_SetGIL(module, Py_MOD_GIL_NOT_USED);
+#endif
+
     if (psutil_setup() != 0)
         INITERROR;
 
@@ -1760,7 +1750,6 @@ void init_psutil_sunos(void)
 
     if (module == NULL)
         INITERROR;
-#if PY_MAJOR_VERSION >= 3
+
     return module;
-#endif
 }
