@@ -31,12 +31,9 @@ def main():
         if os.path.isfile(file):
             md5 = csum(file, "md5")
             sha256 = csum(file, "sha256")
-            print(
-                "%s\nmd5: %s\nsha256: %s\n"
-                % (os.path.basename(file), md5, sha256)
-            )
+            print(f"{os.path.basename(file)}\nmd5: {md5}\nsha256: {sha256}\n")
         else:
-            print("skipping %r (not a file)" % file)
+            print(f"skipping {file!r} (not a file)")
 
 
 if __name__ == "__main__":
