@@ -11,7 +11,6 @@ $ pidof python
 1140 1138 1136 1134 1133 1129 1127 1125 1121 1120 1119
 """
 
-from __future__ import print_function
 
 import sys
 
@@ -19,21 +18,18 @@ import psutil
 
 
 def pidof(pgname):
-    pids = []
-    for proc in psutil.process_iter(['name', 'cmdline']):
-        # search for matches in the process name and cmdline
-        if (
-            proc.info['name'] == pgname
-            or proc.info['cmdline']
-            and proc.info['cmdline'][0] == pgname
-        ):
-            pids.append(str(proc.pid))
-    return pids
+    # search for matches in the process name and cmdline
+    return [
+        str(proc.pid)
+        for proc in psutil.process_iter(['name', 'cmdline'])
+        if proc.info["name"] == pgname
+        or (proc.info["cmdline"] and proc.info["cmdline"][0] == pgname)
+    ]
 
 
 def main():
     if len(sys.argv) != 2:
-        sys.exit('usage: %s pgname' % __file__)
+        sys.exit(f"usage: {__file__} pgname")
     else:
         pgname = sys.argv[1]
     pids = pidof(pgname)
